/*
 * Copyright (C) 2010 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as 
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by Alexandros Frantzis <alexandros.frantzis@linaro.org>
 *
 */

#include <math.h>
#include <glib.h>
#include <stdio.h>
#include <stdlib.h>
#include <strings.h>
#include <clutk/clutk.h>

#define DROP_SHADOW_BLUR   2.0
#define DROP_SHADOW_OFFSET 10
#define ACTOR_SIZE         125
#define TIMELINE_SECONDS   10

void
on_completed (ClutterTimeline* timeline,
              gpointer         data)
{
  clutter_main_quit ();
}

int
main (int    argc,
      char** argv)
{
  ClutterColor     bg_color   = {128, 128, 128, 255};
  ClutterActor*    stage;
  ClutterActor*    actor_blur;
  ClutterActor*    actor_glow;
  ClutterActor*    actor_shadow;
  CtkEffect*       blur;
  CtkEffect*       glow;
  CtkEffect*       shadow;
  ClutterTimeline* timeline;
  gfloat           stage_width;
  gfloat           stage_height;

  /* Make sure rendering is not throttled by sync-to-vblank */
  g_setenv ("CLUTTER_VBLANK", "none", FALSE);

  ctk_init (&argc, &argv);

  /* Create the stage to draw on */
  stage = clutter_stage_get_default ();
  clutter_stage_set_color (CLUTTER_STAGE (stage), &bg_color);
  clutter_actor_get_size (stage, &stage_width, &stage_height);

  /* Create the effects */
  blur = CTK_EFFECT (ctk_effect_blur_new ());
  glow = CTK_EFFECT (ctk_effect_glow_new ());
  shadow = CTK_EFFECT (ctk_effect_drop_shadow_new (DROP_SHADOW_BLUR,
                                                   DROP_SHADOW_OFFSET,
                                                   DROP_SHADOW_OFFSET));

  /* Create the actors and attach effects */
  actor_blur = ctk_image_new_from_filename (ACTOR_SIZE, "./ubuntu.svg");
  actor_glow = ctk_image_new_from_filename (ACTOR_SIZE, "./ubuntu.svg");
  actor_shadow = ctk_image_new_from_filename (ACTOR_SIZE, "./ubuntu.svg");

  ctk_actor_add_effect (CTK_ACTOR (actor_blur), CTK_EFFECT (blur));
  ctk_actor_add_effect (CTK_ACTOR (actor_glow), CTK_EFFECT (glow));
  ctk_actor_add_effect (CTK_ACTOR (actor_shadow), CTK_EFFECT (shadow));

  /* Place actors on the stage */
  clutter_actor_set_anchor_point (actor_blur, ACTOR_SIZE / 2, ACTOR_SIZE / 2);
  clutter_actor_set_position (actor_blur,
                              stage_width / 4,
                              stage_height / 2);

  clutter_actor_set_anchor_point (actor_glow, ACTOR_SIZE / 2, ACTOR_SIZE / 2);
  clutter_actor_set_position (actor_glow,
                              2 * stage_width / 4,
                              stage_height / 2);

  clutter_actor_set_anchor_point (actor_shadow, ACTOR_SIZE / 2, ACTOR_SIZE / 2);
  clutter_actor_set_position (actor_shadow,
                              3 * stage_width / 4,
                              stage_height / 2);

  clutter_container_add_actor (CLUTTER_CONTAINER (stage), actor_blur);
  clutter_container_add_actor (CLUTTER_CONTAINER (stage), actor_glow);
  clutter_container_add_actor (CLUTTER_CONTAINER (stage), actor_shadow);

  /* Make sure we actually see all the actors that have just been created */
  clutter_actor_show_all (stage);

  timeline = clutter_timeline_new (TIMELINE_SECONDS * 1000);
  g_signal_connect (timeline,
                    "completed",
                    G_CALLBACK (on_completed),
                    NULL);

  clutter_timeline_start (timeline);
  clutter_timeline_set_loop (timeline, FALSE);

  clutter_main ();

  return 0;
}

