////////////////////////////////////////////////////////////////////////////////
//3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789 
//      10        20        30        40        50        60        70        80         
//
// Copyright 2010 Canonical Ltd.
//
// This program is free software: you can redistribute it and/or modify it
// under the terms of either or both of the following licenses:
//
// 1) the GNU Lesser General Public License version 3, as published by the
// Free Software Foundation; and/or
// 2) the GNU Lesser General Public License version 2.1, as published by
// the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranties of
// MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
// PURPOSE.  See the applicable version of the GNU Lesser General Public
// License for more details.
//
// You should have received a copy of both the GNU Lesser General Public
// License version 3 and version 2.1 along with this program.  If not, see
// <http://www.gnu.org/licenses/>
//
// Authored by: Mirco Müller <mirco.mueller@canonical.com>
//
////////////////////////////////////////////////////////////////////////////////

//
// how to compile:
//   gcc -Wall -Werror -g -std=c99 `pkg-config --cflags --libs gtk+-2.0
//   clutter-1.0 clutter-gtk-0.10 clutk-0.3` test-ctk-menu-expandable.c
//   -o test-ctk-menu-expandable
//

#include <clutter/clutter.h>
#include <clutk/clutk.h>


gboolean
anim_func (gpointer data)
{
  CtkMenuExpandable* menu   = NULL;
  static gfloat      factor = 0.0f;
  static gfloat      step   = 1.0f / 60.0f;

  menu = CTK_MENU_EXPANDABLE (data);

  if (factor + step > 1.0f)
    step = -1.0f / 60.0f;

  if (factor + step < 0.0f)
    step = 1.0f / 60.0f;

  factor += step;

  ctk_menu_expandable_set_expansion_size_factor (menu, factor);

  clutter_actor_queue_redraw (CLUTTER_ACTOR (menu));

  return TRUE;
}

int
main (int    argc,
      char** argv)
{
  ClutterActor*      stage;
  gint               dummy          = 0;
  ClutterColor       green          = {0, 128, 0, 255};
  ClutterColor       white          = {255, 255, 255, 255};
  ClutterActor*      item_1         = NULL;
  ClutterActor*      item_2         = NULL;
  ClutterActor*      item_3         = NULL;
  ClutterActor*      item_4         = NULL;
  ClutterActor*      item_5         = NULL;
  CtkMenuExpandable* menu           = NULL;
  CtkMenuSeperator*  separator_1    = NULL;
  CtkMenuSeperator*  separator_2    = NULL;
  CtkPadding         padding;
  cairo_surface_t*   surf           = NULL;
  gfloat             rgba[4]        = {0.25f, 0.5f, 1.0f, 1.0f};
  //gfloat             rgba2[4]       = {1.0f, 0.5f, 0.25f, 0.5f};
  gfloat             rgba_tint[4]   = {0.2f, 0.2f, 0.2f, 1.0f};
  gfloat             rgba_hl[4]     = {1.0f, 1.0f, 1.0f, 0.65f};
  gfloat             rgba_line[4]   = {0.8f, 0.8f, 0.8f, 1.0f};
  gfloat             rgba_shadow[4] = {0.0f, 0.0f, 0.0f, 0.75f};
  gfloat             menu_width;
  gfloat             menu_height;
  gfloat             tooltip_width;
  gfloat             tooltip_height;



  // don't sync to vblank, needs to be _before_ clutter_init () !!!
  g_setenv ("CLUTTER_VBLANK", "none", FALSE);

  clutter_init (&dummy, NULL);
  ctk_init (&dummy, NULL);

  stage = clutter_stage_get_default ();
  clutter_stage_set_color (CLUTTER_STAGE (stage), &green);

  item_1 = clutter_text_new_full ("Coconut Medium 9", "Open...", &white);
  clutter_actor_set_reactive (item_1, TRUE);
  item_2 = clutter_text_new_full ("Coconut Medium 9", "Save...", &white);
  clutter_actor_set_reactive (item_2, TRUE);
  item_3 = clutter_text_new_full ("Coconut Medium 9", "Info...", &white);
  clutter_actor_set_reactive (item_3, TRUE);
  item_4 = clutter_text_new_full ("Coconut Medium 9", "Settings...", &white);
  clutter_actor_set_reactive (item_4, TRUE);
  item_5 = clutter_text_new_full ("Coconut Medium 9", "Quit", &white);
  clutter_actor_set_reactive (item_5, TRUE);

  menu = ctk_menu_expandable_new ();
  clutter_actor_set_reactive (CLUTTER_ACTOR (menu), TRUE);

  ctk_menu_append (CTK_MENU (menu), item_1, FALSE);
  ctk_menu_append (CTK_MENU (menu), item_2, FALSE);
  separator_1 = ctk_menu_seperator_new ();
  ctk_menu_append (CTK_MENU (menu), CLUTTER_ACTOR (separator_1), FALSE);
  ctk_menu_append (CTK_MENU (menu), item_3, FALSE);
  ctk_menu_append (CTK_MENU (menu), item_4, FALSE);
  separator_2 = ctk_menu_seperator_new ();
  ctk_menu_append (CTK_MENU (menu), CLUTTER_ACTOR (separator_2), FALSE);
  ctk_menu_append (CTK_MENU (menu), item_5, FALSE);
  clutter_container_add_actor (CLUTTER_CONTAINER (stage),
                               CLUTTER_ACTOR (menu));

 
  ctk_menu_set_spacing (CTK_MENU (menu), 2);
  ctk_menu_expandable_set_content_padding (menu, 4);
  ctk_menu_expandable_set_padding (menu, 16);
  ctk_menu_expandable_compute_style_textures (menu);
  
  ctk_menu_expandable_set_anchor_position (menu, 0, 100, 40);
      
  ctk_menu_expandable_set_expansion_size_factor (menu, 1.0f);

  g_timeout_add (1000/100, anim_func, (gpointer) menu);

  clutter_actor_show_all (stage);

  clutter_main ();

  return 0;
}